spv, which takes lists of
experimental designs and / or model formulae and produces samples throughout the design region
at which the prediction variance is evaluated. Depending on the type of input for the
design and formula arguments, spv creates output objects of S3 classes
spv, spvlist, spvforlist or spvlistforlist. The graphical output are
obtained with the plot methods of these classes, and the which argument
can be used to control the type of plots produced. The design regions allowed for are typically spherical or cuboidal in nature, but the
keepfun argument to spv can be used for rejection sampling. In this way
nonstandard design regions can be allowed for. See also the type argument of spv.
The output from the plot methods for objects created by spv are
typically named lists of graphical objects created by ggplot2. These are best stored in an
object and recreated by printing the required plot. Storing such graphical objects also enables
post-hoc manipulation of the plots, such as changing the background colour by using
ggplot2's theme function.
spv, plot.spv, and vignette(topic = "vdg").